Store context options on caps.

Committed: https://skia.googlesource.com/skia/+/f28cff71db2cbb1ff18a8fbf1e80ca761d1f69bc

Review URL: https://codereview.chromium.org/1158433006
diff --git a/include/gpu/GrTypesPriv.h b/include/gpu/GrTypesPriv.h
index eaf1aa4..9202742 100644
--- a/include/gpu/GrTypesPriv.h
+++ b/include/gpu/GrTypesPriv.h
@@ -265,13 +265,13 @@
 };
 
 #ifdef SK_DEBUG
-// Takes a pointer to a GrContext, and will suppress prints if required
-#define GrContextDebugf(context, ...) \
-    if (!context->suppressPrints()) {         \
-        SkDebugf(__VA_ARGS__);      \
+// Takes a pointer to a GrCaps, and will suppress prints if required
+#define GrCapsDebugf(caps, ...)         \
+    if (!caps->suppressPrints()) {      \
+        SkDebugf(__VA_ARGS__);          \
     }
 #else
-#define GrContextDebugf(context, ...)
+#define GrCapsDebugf(caps, ...)
 #endif
 
 #endif